@@ -9,5 +9,9 @@ class AIOGitHubAPIRatelimitException(AIOGitHubAPIException):
     """Raise this when we hit the ratelimit."""
 
 
+class AIOGitHubAPINotModifiedException(AIOGitHubAPIException):
+    """Raise this when we the content was not modified."""
+
+
 class AIOGitHubAPIAuthenticationException(AIOGitHubAPIException):
     """Raise this when there is an authentication issue."""
